import { PropType, ExtractPropTypes, InjectionKey } from 'vue';
import { Key } from 'treemate';
import { MaybeArray } from '../../_utils';
import { MenuInjection } from './use-menu-child';
import { MenuOption, MenuGroupOption, OnUpdateValue, OnUpdateKeys } from './interface';
declare const menuProps: {
    readonly options: {
        readonly type: PropType<(MenuOption | MenuGroupOption)[]>;
        readonly default: () => never[];
    };
    readonly items: {
        readonly type: PropType<(MenuOption | MenuGroupOption)[] | undefined>;
        readonly validator: () => boolean;
        readonly default: undefined;
    };
    readonly collapsed: {
        readonly type: PropType<boolean | undefined>;
        readonly default: undefined;
    };
    readonly collapsedWidth: {
        readonly type: NumberConstructor;
        readonly default: 48;
    };
    readonly iconSize: {
        readonly type: NumberConstructor;
        readonly default: 20;
    };
    readonly collapsedIconSize: {
        readonly type: NumberConstructor;
        readonly default: 24;
    };
    readonly rootIndent: NumberConstructor;
    readonly indent: {
        readonly type: NumberConstructor;
        readonly default: 32;
    };
    readonly defaultExpandAll: BooleanConstructor;
    readonly defaultExpandedKeys: {
        readonly type: PropType<Key[]>;
        readonly default: () => never[];
    };
    readonly expandedKeys: {
        readonly type: PropType<Key[]>;
        readonly default: undefined;
    };
    readonly value: PropType<Key | null>;
    readonly defaultValue: {
        readonly type: PropType<Key | null>;
        readonly default: null;
    };
    readonly mode: {
        readonly type: PropType<"horizontal" | "vertical">;
        readonly default: "vertical";
    };
    readonly disabled: BooleanConstructor;
    readonly inverted: BooleanConstructor;
    readonly 'onUpdate:expandedKeys': PropType<MaybeArray<OnUpdateKeys>>;
    readonly onUpdateExpandedKeys: PropType<MaybeArray<OnUpdateKeys>>;
    readonly onUpdateValue: PropType<MaybeArray<OnUpdateValue>>;
    readonly 'onUpdate:value': PropType<MaybeArray<OnUpdateValue>>;
    readonly onOpenNamesChange: {
        readonly type: PropType<MaybeArray<OnUpdateKeys>>;
        readonly validator: () => boolean;
        readonly default: undefined;
    };
    readonly onSelect: {
        readonly type: PropType<MaybeArray<OnUpdateValue>>;
        readonly validator: () => boolean;
        readonly default: undefined;
    };
    readonly onExpandedNamesChange: {
        readonly type: PropType<MaybeArray<OnUpdateKeys>>;
        readonly validator: () => boolean;
        readonly default: undefined;
    };
    readonly expandedNames: {
        readonly type: PropType<Key[]>;
        readonly validator: () => boolean;
        readonly default: undefined;
    };
    readonly defaultExpandedNames: {
        readonly type: PropType<Key[]>;
        readonly validator: () => boolean;
        readonly default: undefined;
    };
    readonly theme: PropType<import("../../_mixins").Theme<"Menu", {
        itemTextColorInverted: string;
        itemTextColorHoverInverted: string;
        itemTextColorChildActiveInverted: string;
        itemTextColorActiveInverted: string;
        itemIconColorInverted: string;
        itemIconColorHoverInverted: string;
        itemIconColorActiveInverted: string;
        itemIconColorChildActiveInverted: string;
        itemIconColorCollapsedInverted: string;
        arrowColorInverted: string;
        arrowColorHoverInverted: string;
        arrowColorChildActiveInverted: string;
        arrowColorActiveInverted: string;
        groupTextColorInverted: string;
        borderRadius: string;
        color: string;
        groupTextColor: string;
        itemColorActive: string;
        itemColorActiveCollapsed: string;
        itemTextColor: string;
        itemTextColorHover: string;
        itemTextColorChildActive: string;
        itemTextColorActive: string;
        itemIconColor: string;
        itemIconColorHover: string;
        itemIconColorActive: string;
        itemIconColorChildActive: string;
        itemIconColorCollapsed: string;
        arrowColor: string;
        arrowColorHover: string;
        arrowColorChildActive: string;
        arrowColorActive: string;
        colorInverted: string;
        itemColorActiveInverted: string;
        itemColorActiveCollapsedInverted: string;
        borderColorHorizontal: string;
        fontSize: string;
    }, {
        Tooltip: import("../../_mixins").Theme<"Tooltip", {
            borderRadius: string;
            boxShadow: string;
            color: string;
            textColor: string;
            padding: string;
        }, {
            Popover: import("../../_mixins").Theme<"Popover", {
                fontSize: string;
                borderRadius: string;
                color: string;
                textColor: string;
                boxShadow: string;
                space: string;
                spaceArrow: string;
                arrowOffset: string;
                arrowOffsetVertical: string;
                arrowHeight: string;
                padding: string;
            }, any>;
        }>;
    }>>;
    readonly themeOverrides: PropType<import("../../_mixins/use-theme").ExtractThemeOverrides<import("../../_mixins").Theme<"Menu", {
        itemTextColorInverted: string;
        itemTextColorHoverInverted: string;
        itemTextColorChildActiveInverted: string;
        itemTextColorActiveInverted: string;
        itemIconColorInverted: string;
        itemIconColorHoverInverted: string;
        itemIconColorActiveInverted: string;
        itemIconColorChildActiveInverted: string;
        itemIconColorCollapsedInverted: string;
        arrowColorInverted: string;
        arrowColorHoverInverted: string;
        arrowColorChildActiveInverted: string;
        arrowColorActiveInverted: string;
        groupTextColorInverted: string;
        borderRadius: string;
        color: string;
        groupTextColor: string;
        itemColorActive: string;
        itemColorActiveCollapsed: string;
        itemTextColor: string;
        itemTextColorHover: string;
        itemTextColorChildActive: string;
        itemTextColorActive: string;
        itemIconColor: string;
        itemIconColorHover: string;
        itemIconColorActive: string;
        itemIconColorChildActive: string;
        itemIconColorCollapsed: string;
        arrowColor: string;
        arrowColorHover: string;
        arrowColorChildActive: string;
        arrowColorActive: string;
        colorInverted: string;
        itemColorActiveInverted: string;
        itemColorActiveCollapsedInverted: string;
        borderColorHorizontal: string;
        fontSize: string;
    }, {
        Tooltip: import("../../_mixins").Theme<"Tooltip", {
            borderRadius: string;
            boxShadow: string;
            color: string;
            textColor: string;
            padding: string;
        }, {
            Popover: import("../../_mixins").Theme<"Popover", {
                fontSize: string;
                borderRadius: string;
                color: string;
                textColor: string;
                boxShadow: string;
                space: string;
                spaceArrow: string;
                arrowOffset: string;
                arrowOffsetVertical: string;
                arrowHeight: string;
                padding: string;
            }, any>;
        }>;
    }>>>;
    readonly builtinThemeOverrides: PropType<import("../../_mixins/use-theme").ExtractThemeOverrides<import("../../_mixins").Theme<"Menu", {
        itemTextColorInverted: string;
        itemTextColorHoverInverted: string;
        itemTextColorChildActiveInverted: string;
        itemTextColorActiveInverted: string;
        itemIconColorInverted: string;
        itemIconColorHoverInverted: string;
        itemIconColorActiveInverted: string;
        itemIconColorChildActiveInverted: string;
        itemIconColorCollapsedInverted: string;
        arrowColorInverted: string;
        arrowColorHoverInverted: string;
        arrowColorChildActiveInverted: string;
        arrowColorActiveInverted: string;
        groupTextColorInverted: string;
        borderRadius: string;
        color: string;
        groupTextColor: string;
        itemColorActive: string;
        itemColorActiveCollapsed: string;
        itemTextColor: string;
        itemTextColorHover: string;
        itemTextColorChildActive: string;
        itemTextColorActive: string;
        itemIconColor: string;
        itemIconColorHover: string;
        itemIconColorActive: string;
        itemIconColorChildActive: string;
        itemIconColorCollapsed: string;
        arrowColor: string;
        arrowColorHover: string;
        arrowColorChildActive: string;
        arrowColorActive: string;
        colorInverted: string;
        itemColorActiveInverted: string;
        itemColorActiveCollapsedInverted: string;
        borderColorHorizontal: string;
        fontSize: string;
    }, {
        Tooltip: import("../../_mixins").Theme<"Tooltip", {
            borderRadius: string;
            boxShadow: string;
            color: string;
            textColor: string;
            padding: string;
        }, {
            Popover: import("../../_mixins").Theme<"Popover", {
                fontSize: string;
                borderRadius: string;
                color: string;
                textColor: string;
                boxShadow: string;
                space: string;
                spaceArrow: string;
                arrowOffset: string;
                arrowOffsetVertical: string;
                arrowHeight: string;
                padding: string;
            }, any>;
        }>;
    }>>>;
};
export declare type MenuSetupProps = ExtractPropTypes<typeof menuProps>;
export declare type MenuProps = Partial<MenuSetupProps>;
export declare const menuInjectionKey: InjectionKey<MenuInjection>;
declare const _default: import("vue").DefineComponent<{
    readonly options: {
        readonly type: PropType<(MenuOption | MenuGroupOption)[]>;
        readonly default: () => never[];
    };
    readonly items: {
        readonly type: PropType<(MenuOption | MenuGroupOption)[] | undefined>;
        readonly validator: () => boolean;
        readonly default: undefined;
    };
    readonly collapsed: {
        readonly type: PropType<boolean | undefined>;
        readonly default: undefined;
    };
    readonly collapsedWidth: {
        readonly type: NumberConstructor;
        readonly default: 48;
    };
    readonly iconSize: {
        readonly type: NumberConstructor;
        readonly default: 20;
    };
    readonly collapsedIconSize: {
        readonly type: NumberConstructor;
        readonly default: 24;
    };
    readonly rootIndent: NumberConstructor;
    readonly indent: {
        readonly type: NumberConstructor;
        readonly default: 32;
    };
    readonly defaultExpandAll: BooleanConstructor;
    readonly defaultExpandedKeys: {
        readonly type: PropType<Key[]>;
        readonly default: () => never[];
    };
    readonly expandedKeys: {
        readonly type: PropType<Key[]>;
        readonly default: undefined;
    };
    readonly value: PropType<Key | null>;
    readonly defaultValue: {
        readonly type: PropType<Key | null>;
        readonly default: null;
    };
    readonly mode: {
        readonly type: PropType<"horizontal" | "vertical">;
        readonly default: "vertical";
    };
    readonly disabled: BooleanConstructor;
    readonly inverted: BooleanConstructor;
    readonly 'onUpdate:expandedKeys': PropType<MaybeArray<OnUpdateKeys>>;
    readonly onUpdateExpandedKeys: PropType<MaybeArray<OnUpdateKeys>>;
    readonly onUpdateValue: PropType<MaybeArray<OnUpdateValue>>;
    readonly 'onUpdate:value': PropType<MaybeArray<OnUpdateValue>>;
    readonly onOpenNamesChange: {
        readonly type: PropType<MaybeArray<OnUpdateKeys>>;
        readonly validator: () => boolean;
        readonly default: undefined;
    };
    readonly onSelect: {
        readonly type: PropType<MaybeArray<OnUpdateValue>>;
        readonly validator: () => boolean;
        readonly default: undefined;
    };
    readonly onExpandedNamesChange: {
        readonly type: PropType<MaybeArray<OnUpdateKeys>>;
        readonly validator: () => boolean;
        readonly default: undefined;
    };
    readonly expandedNames: {
        readonly type: PropType<Key[]>;
        readonly validator: () => boolean;
        readonly default: undefined;
    };
    readonly defaultExpandedNames: {
        readonly type: PropType<Key[]>;
        readonly validator: () => boolean;
        readonly default: undefined;
    };
    readonly theme: PropType<import("../../_mixins").Theme<"Menu", {
        itemTextColorInverted: string;
        itemTextColorHoverInverted: string;
        itemTextColorChildActiveInverted: string;
        itemTextColorActiveInverted: string;
        itemIconColorInverted: string;
        itemIconColorHoverInverted: string;
        itemIconColorActiveInverted: string;
        itemIconColorChildActiveInverted: string;
        itemIconColorCollapsedInverted: string;
        arrowColorInverted: string;
        arrowColorHoverInverted: string;
        arrowColorChildActiveInverted: string;
        arrowColorActiveInverted: string;
        groupTextColorInverted: string;
        borderRadius: string;
        color: string;
        groupTextColor: string;
        itemColorActive: string;
        itemColorActiveCollapsed: string;
        itemTextColor: string;
        itemTextColorHover: string;
        itemTextColorChildActive: string;
        itemTextColorActive: string;
        itemIconColor: string;
        itemIconColorHover: string;
        itemIconColorActive: string;
        itemIconColorChildActive: string;
        itemIconColorCollapsed: string;
        arrowColor: string;
        arrowColorHover: string;
        arrowColorChildActive: string;
        arrowColorActive: string;
        colorInverted: string;
        itemColorActiveInverted: string;
        itemColorActiveCollapsedInverted: string;
        borderColorHorizontal: string;
        fontSize: string;
    }, {
        Tooltip: import("../../_mixins").Theme<"Tooltip", {
            borderRadius: string;
            boxShadow: string;
            color: string;
            textColor: string;
            padding: string;
        }, {
            Popover: import("../../_mixins").Theme<"Popover", {
                fontSize: string;
                borderRadius: string;
                color: string;
                textColor: string;
                boxShadow: string;
                space: string;
                spaceArrow: string;
                arrowOffset: string;
                arrowOffsetVertical: string;
                arrowHeight: string;
                padding: string;
            }, any>;
        }>;
    }>>;
    readonly themeOverrides: PropType<import("../../_mixins/use-theme").ExtractThemeOverrides<import("../../_mixins").Theme<"Menu", {
        itemTextColorInverted: string;
        itemTextColorHoverInverted: string;
        itemTextColorChildActiveInverted: string;
        itemTextColorActiveInverted: string;
        itemIconColorInverted: string;
        itemIconColorHoverInverted: string;
        itemIconColorActiveInverted: string;
        itemIconColorChildActiveInverted: string;
        itemIconColorCollapsedInverted: string;
        arrowColorInverted: string;
        arrowColorHoverInverted: string;
        arrowColorChildActiveInverted: string;
        arrowColorActiveInverted: string;
        groupTextColorInverted: string;
        borderRadius: string;
        color: string;
        groupTextColor: string;
        itemColorActive: string;
        itemColorActiveCollapsed: string;
        itemTextColor: string;
        itemTextColorHover: string;
        itemTextColorChildActive: string;
        itemTextColorActive: string;
        itemIconColor: string;
        itemIconColorHover: string;
        itemIconColorActive: string;
        itemIconColorChildActive: string;
        itemIconColorCollapsed: string;
        arrowColor: string;
        arrowColorHover: string;
        arrowColorChildActive: string;
        arrowColorActive: string;
        colorInverted: string;
        itemColorActiveInverted: string;
        itemColorActiveCollapsedInverted: string;
        borderColorHorizontal: string;
        fontSize: string;
    }, {
        Tooltip: import("../../_mixins").Theme<"Tooltip", {
            borderRadius: string;
            boxShadow: string;
            color: string;
            textColor: string;
            padding: string;
        }, {
            Popover: import("../../_mixins").Theme<"Popover", {
                fontSize: string;
                borderRadius: string;
                color: string;
                textColor: string;
                boxShadow: string;
                space: string;
                spaceArrow: string;
                arrowOffset: string;
                arrowOffsetVertical: string;
                arrowHeight: string;
                padding: string;
            }, any>;
        }>;
    }>>>;
    readonly builtinThemeOverrides: PropType<import("../../_mixins/use-theme").ExtractThemeOverrides<import("../../_mixins").Theme<"Menu", {
        itemTextColorInverted: string;
        itemTextColorHoverInverted: string;
        itemTextColorChildActiveInverted: string;
        itemTextColorActiveInverted: string;
        itemIconColorInverted: string;
        itemIconColorHoverInverted: string;
        itemIconColorActiveInverted: string;
        itemIconColorChildActiveInverted: string;
        itemIconColorCollapsedInverted: string;
        arrowColorInverted: string;
        arrowColorHoverInverted: string;
        arrowColorChildActiveInverted: string;
        arrowColorActiveInverted: string;
        groupTextColorInverted: string;
        borderRadius: string;
        color: string;
        groupTextColor: string;
        itemColorActive: string;
        itemColorActiveCollapsed: string;
        itemTextColor: string;
        itemTextColorHover: string;
        itemTextColorChildActive: string;
        itemTextColorActive: string;
        itemIconColor: string;
        itemIconColorHover: string;
        itemIconColorActive: string;
        itemIconColorChildActive: string;
        itemIconColorCollapsed: string;
        arrowColor: string;
        arrowColorHover: string;
        arrowColorChildActive: string;
        arrowColorActive: string;
        colorInverted: string;
        itemColorActiveInverted: string;
        itemColorActiveCollapsedInverted: string;
        borderColorHorizontal: string;
        fontSize: string;
    }, {
        Tooltip: import("../../_mixins").Theme<"Tooltip", {
            borderRadius: string;
            boxShadow: string;
            color: string;
            textColor: string;
            padding: string;
        }, {
            Popover: import("../../_mixins").Theme<"Popover", {
                fontSize: string;
                borderRadius: string;
                color: string;
                textColor: string;
                boxShadow: string;
                space: string;
                spaceArrow: string;
                arrowOffset: string;
                arrowOffsetVertical: string;
                arrowHeight: string;
                padding: string;
            }, any>;
        }>;
    }>>>;
}, {
    mergedClsPrefix: import("vue").ComputedRef<string>;
    controlledExpandedKeys: import("vue").ComputedRef<Key[] | undefined>;
    uncontrolledExpanededKeys: import("vue").Ref<Key[]>;
    mergedExpandedKeys: import("vue").ComputedRef<Key[]>;
    uncontrolledValue: import("vue").Ref<Key | null>;
    mergedValue: import("vue").ComputedRef<Key | null>;
    activePath: import("vue").ComputedRef<Key[]>;
    tmNodes: import("vue").ComputedRef<import("treemate").TreeNode<MenuOption, MenuGroupOption, MenuOption>[]>;
    mergedTheme: import("vue").ComputedRef<{
        common: {
            baseColor: string;
            primaryColor: string;
            primaryColorHover: string;
            primaryColorPressed: string;
            primaryColorSuppl: string;
            infoColor: string;
            infoColorHover: string;
            infoColorPressed: string;
            infoColorSuppl: string;
            successColor: string;
            successColorHover: string;
            successColorPressed: string;
            successColorSuppl: string;
            warningColor: string;
            warningColorHover: string;
            warningColorPressed: string;
            warningColorSuppl: string;
            errorColor: string;
            errorColorHover: string;
            errorColorPressed: string;
            errorColorSuppl: string;
            textColorBase: string;
            textColor1: string;
            textColor2: string;
            textColor3: string;
            textColorDisabled: string;
            placeholderColor: string;
            placeholderColorDisabled: string;
            iconColor: string;
            iconColorDisabled: string;
            opacity1: string;
            opacity2: string;
            opacity3: string;
            opacity4: string;
            opacity5: string;
            dividerColor: string;
            borderColor: string;
            closeColor: string;
            closeColorHover: string;
            closeColorPressed: string;
            closeColorDisabled: string;
            closeOpacity: string;
            closeOpacityHover: string;
            closeOpacityPressed: string;
            clearColor: string;
            clearColorHover: string;
            clearColorPressed: string;
            scrollbarColor: string;
            scrollbarColorHover: string;
            progressRailColor: string;
            railColor: string;
            popoverColor: string;
            tableColor: string;
            cardColor: string;
            modalColor: string;
            bodyColor: string;
            tagColor: string;
            avatarColor: string;
            invertedColor: string;
            inputColor: string;
            codeColor: string;
            tabColor: string;
            actionColor: string;
            tableHeaderColor: string;
            hoverColor: string;
            tableColorHover: string;
            pressedColor: string;
            opacityDisabled: string;
            inputColorDisabled: string;
            boxShadow1: string;
            boxShadow2: string;
            boxShadow3: string;
            fontFamily: string;
            fontFamilyMono: string;
            fontWeight: string;
            fontWeightStrong: string;
            cubicBezierEaseInOut: string;
            cubicBezierEaseOut: string;
            cubicBezierEaseIn: string;
            borderRadius: string;
            borderRadiusSmall: string;
            fontSize: string;
            fontSizeTiny: string;
            fontSizeSmall: string;
            fontSizeMedium: string;
            fontSizeLarge: string;
            fontSizeHuge: string;
            lineHeight: string;
            heightTiny: string;
            heightSmall: string;
            heightMedium: string;
            heightLarge: string;
            heightHuge: string;
            transformDebounceScale: string;
            name: "common";
        };
        self: {
            itemTextColorInverted: string;
            itemTextColorHoverInverted: string;
            itemTextColorChildActiveInverted: string;
            itemTextColorActiveInverted: string;
            itemIconColorInverted: string;
            itemIconColorHoverInverted: string;
            itemIconColorActiveInverted: string;
            itemIconColorChildActiveInverted: string;
            itemIconColorCollapsedInverted: string;
            arrowColorInverted: string;
            arrowColorHoverInverted: string;
            arrowColorChildActiveInverted: string;
            arrowColorActiveInverted: string;
            groupTextColorInverted: string;
            borderRadius: string;
            color: string;
            groupTextColor: string;
            itemColorActive: string;
            itemColorActiveCollapsed: string;
            itemTextColor: string;
            itemTextColorHover: string;
            itemTextColorChildActive: string;
            itemTextColorActive: string;
            itemIconColor: string;
            itemIconColorHover: string;
            itemIconColorActive: string;
            itemIconColorChildActive: string;
            itemIconColorCollapsed: string;
            arrowColor: string;
            arrowColorHover: string;
            arrowColorChildActive: string;
            arrowColorActive: string;
            colorInverted: string;
            itemColorActiveInverted: string;
            itemColorActiveCollapsedInverted: string;
            borderColorHorizontal: string;
            fontSize: string;
        };
        peers: {
            Tooltip: import("../../_mixins").Theme<"Tooltip", {
                borderRadius: string;
                boxShadow: string;
                color: string;
                textColor: string;
                padding: string;
            }, {
                Popover: import("../../_mixins").Theme<"Popover", {
                    fontSize: string;
                    borderRadius: string;
                    color: string;
                    textColor: string;
                    boxShadow: string;
                    space: string;
                    spaceArrow: string;
                    arrowOffset: string;
                    arrowOffsetVertical: string;
                    arrowHeight: string;
                    padding: string;
                }, any>;
            }>;
        };
        peerOverrides: {
            Tooltip?: {
                peers?: {
                    Popover?: import("../../_mixins/use-theme").ExtractThemeOverrides<import("../../_mixins").Theme<"Popover", {
                        fontSize: string;
                        borderRadius: string;
                        color: string;
                        textColor: string;
                        boxShadow: string;
                        space: string;
                        spaceArrow: string;
                        arrowOffset: string;
                        arrowOffsetVertical: string;
                        arrowHeight: string;
                        padding: string;
                    }, any>> | undefined;
                } | undefined;
            } | undefined;
        };
    }>;
    mergedCollapsed: import("vue").ComputedRef<boolean>;
    cssVars: import("vue").ComputedRef<any>;
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    mode: "horizontal" | "vertical";
    disabled: boolean;
    iconSize: number;
    options: (MenuOption | MenuGroupOption)[];
    defaultValue: Key | null;
    indent: number;
    inverted: boolean;
    collapsedWidth: number;
    collapsedIconSize: number;
    defaultExpandAll: boolean;
    defaultExpandedKeys: Key[];
} & {
    value?: Key | null | undefined;
    onSelect?: MaybeArray<OnUpdateValue> | undefined;
    theme?: import("../../_mixins").Theme<"Menu", {
        itemTextColorInverted: string;
        itemTextColorHoverInverted: string;
        itemTextColorChildActiveInverted: string;
        itemTextColorActiveInverted: string;
        itemIconColorInverted: string;
        itemIconColorHoverInverted: string;
        itemIconColorActiveInverted: string;
        itemIconColorChildActiveInverted: string;
        itemIconColorCollapsedInverted: string;
        arrowColorInverted: string;
        arrowColorHoverInverted: string;
        arrowColorChildActiveInverted: string;
        arrowColorActiveInverted: string;
        groupTextColorInverted: string;
        borderRadius: string;
        color: string;
        groupTextColor: string;
        itemColorActive: string;
        itemColorActiveCollapsed: string;
        itemTextColor: string;
        itemTextColorHover: string;
        itemTextColorChildActive: string;
        itemTextColorActive: string;
        itemIconColor: string;
        itemIconColorHover: string;
        itemIconColorActive: string;
        itemIconColorChildActive: string;
        itemIconColorCollapsed: string;
        arrowColor: string;
        arrowColorHover: string;
        arrowColorChildActive: string;
        arrowColorActive: string;
        colorInverted: string;
        itemColorActiveInverted: string;
        itemColorActiveCollapsedInverted: string;
        borderColorHorizontal: string;
        fontSize: string;
    }, {
        Tooltip: import("../../_mixins").Theme<"Tooltip", {
            borderRadius: string;
            boxShadow: string;
            color: string;
            textColor: string;
            padding: string;
        }, {
            Popover: import("../../_mixins").Theme<"Popover", {
                fontSize: string;
                borderRadius: string;
                color: string;
                textColor: string;
                boxShadow: string;
                space: string;
                spaceArrow: string;
                arrowOffset: string;
                arrowOffsetVertical: string;
                arrowHeight: string;
                padding: string;
            }, any>;
        }>;
    }> | undefined;
    themeOverrides?: import("../../_mixins/use-theme").ExtractThemeOverrides<import("../../_mixins").Theme<"Menu", {
        itemTextColorInverted: string;
        itemTextColorHoverInverted: string;
        itemTextColorChildActiveInverted: string;
        itemTextColorActiveInverted: string;
        itemIconColorInverted: string;
        itemIconColorHoverInverted: string;
        itemIconColorActiveInverted: string;
        itemIconColorChildActiveInverted: string;
        itemIconColorCollapsedInverted: string;
        arrowColorInverted: string;
        arrowColorHoverInverted: string;
        arrowColorChildActiveInverted: string;
        arrowColorActiveInverted: string;
        groupTextColorInverted: string;
        borderRadius: string;
        color: string;
        groupTextColor: string;
        itemColorActive: string;
        itemColorActiveCollapsed: string;
        itemTextColor: string;
        itemTextColorHover: string;
        itemTextColorChildActive: string;
        itemTextColorActive: string;
        itemIconColor: string;
        itemIconColorHover: string;
        itemIconColorActive: string;
        itemIconColorChildActive: string;
        itemIconColorCollapsed: string;
        arrowColor: string;
        arrowColorHover: string;
        arrowColorChildActive: string;
        arrowColorActive: string;
        colorInverted: string;
        itemColorActiveInverted: string;
        itemColorActiveCollapsedInverted: string;
        borderColorHorizontal: string;
        fontSize: string;
    }, {
        Tooltip: import("../../_mixins").Theme<"Tooltip", {
            borderRadius: string;
            boxShadow: string;
            color: string;
            textColor: string;
            padding: string;
        }, {
            Popover: import("../../_mixins").Theme<"Popover", {
                fontSize: string;
                borderRadius: string;
                color: string;
                textColor: string;
                boxShadow: string;
                space: string;
                spaceArrow: string;
                arrowOffset: string;
                arrowOffsetVertical: string;
                arrowHeight: string;
                padding: string;
            }, any>;
        }>;
    }>> | undefined;
    builtinThemeOverrides?: import("../../_mixins/use-theme").ExtractThemeOverrides<import("../../_mixins").Theme<"Menu", {
        itemTextColorInverted: string;
        itemTextColorHoverInverted: string;
        itemTextColorChildActiveInverted: string;
        itemTextColorActiveInverted: string;
        itemIconColorInverted: string;
        itemIconColorHoverInverted: string;
        itemIconColorActiveInverted: string;
        itemIconColorChildActiveInverted: string;
        itemIconColorCollapsedInverted: string;
        arrowColorInverted: string;
        arrowColorHoverInverted: string;
        arrowColorChildActiveInverted: string;
        arrowColorActiveInverted: string;
        groupTextColorInverted: string;
        borderRadius: string;
        color: string;
        groupTextColor: string;
        itemColorActive: string;
        itemColorActiveCollapsed: string;
        itemTextColor: string;
        itemTextColorHover: string;
        itemTextColorChildActive: string;
        itemTextColorActive: string;
        itemIconColor: string;
        itemIconColorHover: string;
        itemIconColorActive: string;
        itemIconColorChildActive: string;
        itemIconColorCollapsed: string;
        arrowColor: string;
        arrowColorHover: string;
        arrowColorChildActive: string;
        arrowColorActive: string;
        colorInverted: string;
        itemColorActiveInverted: string;
        itemColorActiveCollapsedInverted: string;
        borderColorHorizontal: string;
        fontSize: string;
    }, {
        Tooltip: import("../../_mixins").Theme<"Tooltip", {
            borderRadius: string;
            boxShadow: string;
            color: string;
            textColor: string;
            padding: string;
        }, {
            Popover: import("../../_mixins").Theme<"Popover", {
                fontSize: string;
                borderRadius: string;
                color: string;
                textColor: string;
                boxShadow: string;
                space: string;
                spaceArrow: string;
                arrowOffset: string;
                arrowOffsetVertical: string;
                arrowHeight: string;
                padding: string;
            }, any>;
        }>;
    }>> | undefined;
    items?: (MenuOption | MenuGroupOption)[] | undefined;
    "onUpdate:value"?: MaybeArray<OnUpdateValue> | undefined;
    onUpdateValue?: MaybeArray<OnUpdateValue> | undefined;
    defaultExpandedNames?: Key[] | undefined;
    expandedNames?: Key[] | undefined;
    onExpandedNamesChange?: MaybeArray<OnUpdateKeys> | undefined;
    collapsed?: boolean | undefined;
    rootIndent?: number | undefined;
    expandedKeys?: Key[] | undefined;
    "onUpdate:expandedKeys"?: MaybeArray<OnUpdateKeys> | undefined;
    onUpdateExpandedKeys?: MaybeArray<OnUpdateKeys> | undefined;
    onOpenNamesChange?: MaybeArray<OnUpdateKeys> | undefined;
}>, {
    mode: "horizontal" | "vertical";
    disabled: boolean;
    onSelect: MaybeArray<OnUpdateValue>;
    items: (MenuOption | MenuGroupOption)[] | undefined;
    iconSize: number;
    options: (MenuOption | MenuGroupOption)[];
    defaultValue: Key | null;
    indent: number;
    inverted: boolean;
    defaultExpandedNames: Key[];
    expandedNames: Key[];
    onExpandedNamesChange: MaybeArray<OnUpdateKeys>;
    collapsed: boolean | undefined;
    collapsedWidth: number;
    collapsedIconSize: number;
    defaultExpandAll: boolean;
    defaultExpandedKeys: Key[];
    expandedKeys: Key[];
    onOpenNamesChange: MaybeArray<OnUpdateKeys>;
}>;
export default _default;
