"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vue_1 = require("vue");
const _internal_1 = require("../../_internal");
const icons_1 = require("../../_internal/icons");
const iconMap = {
    success: vue_1.h(icons_1.SuccessIcon, null),
    error: vue_1.h(icons_1.ErrorIcon, null),
    warning: vue_1.h(icons_1.WarningIcon, null),
    info: vue_1.h(icons_1.InfoIcon, null)
};
exports.default = vue_1.defineComponent({
    name: 'ProgressCircle',
    props: {
        clsPrefix: {
            type: String,
            required: true
        },
        status: {
            type: String,
            required: true
        },
        strokeWidth: {
            type: Number,
            required: true
        },
        fillColor: String,
        railColor: String,
        railStyle: [String, Object],
        percentage: {
            type: Number,
            required: true
        },
        showIndicator: {
            type: Boolean,
            reqiuired: true
        },
        indicatorTextColor: String,
        unit: String,
        viewBoxWidth: {
            type: Number,
            required: true
        }
    },
    setup(props, { slots }) {
        const strokeDasharrayRef = vue_1.computed(() => {
            return `${Math.PI * props.percentage}, ${props.viewBoxWidth * 8}`;
        });
        return () => {
            const { fillColor, railColor, railStyle, strokeWidth, status, percentage, showIndicator, indicatorTextColor, unit, clsPrefix } = props;
            return (vue_1.h("div", { class: `${clsPrefix}-progress-content` },
                vue_1.h("div", { class: `${clsPrefix}-progress-graph` },
                    vue_1.h("div", { class: `${clsPrefix}-progress-graph-circle` },
                        vue_1.h("svg", { viewBox: "0 0 110 110" },
                            vue_1.h("g", null,
                                vue_1.h("path", { class: `${clsPrefix}-progress-graph-circle-rail`, d: "m 55 5 a 50 50 0 1 1 0 100 a 50 50 0 1 1 0 -100", "stroke-width": strokeWidth * 1.1, "stroke-linecap": "round", fill: "none", style: [
                                        {
                                            strokeDashoffset: 0,
                                            stroke: railColor
                                        },
                                        railStyle
                                    ] })),
                            vue_1.h("g", null,
                                vue_1.h("path", { class: [
                                        `${clsPrefix}-progress-graph-circle-fill`,
                                        percentage === 0 &&
                                            `${clsPrefix}-progress-graph-circle-fill--empty`
                                    ], d: "m 55 5 a 50 50 0 1 1 0 100 a 50 50 0 1 1 0 -100", "stroke-width": strokeWidth * 1.1, "stroke-linecap": "round", fill: "none", style: {
                                        strokeDasharray: strokeDasharrayRef.value,
                                        strokeDashoffset: 0,
                                        stroke: fillColor
                                    } }))))),
                showIndicator ? (vue_1.h("div", null, slots.default ? (vue_1.h("div", { class: `${clsPrefix}-progress-custom-content` }, slots.default())) : status !== 'default' ? (vue_1.h("div", { class: `${clsPrefix}-progress-icon` },
                    vue_1.h(_internal_1.NBaseIcon, { clsPrefix: clsPrefix }, {
                        default: () => iconMap[status]
                    }))) : (vue_1.h("div", { class: `${clsPrefix}-progress-text`, style: {
                        color: indicatorTextColor
                    } },
                    vue_1.h("span", { class: `${clsPrefix}-progress-text__percentage` }, percentage),
                    vue_1.h("span", { class: `${clsPrefix}-progress-text__unit` }, unit))))) : null));
        };
    }
});
